from os.path import abspath, dirname, join
from pytest import raises
from linkahead import get_connection, configure_connection, Record
from linkahead.connection.mockup import (MockUpServerConnection, MockUpResponse)
from caosadvancedtools.serverside.helper import get_data
from loan.box_loan import (PERSON, FIRST_NAME, EMAIL, BOX, BORROWER,
                         EXPECTED_RETURN, EXHAUST_CONTENTS, COMMENT,
                         DESTINATION, F_FIRST_NAME, F_EMAIL,
                         F_EXPECTED_RETURN_DATE, DataError, BOX_NUMBER)
from loan.request_loan import (create_loan, _issue_loan_request)
from utils import get_form_data_example


def test_issue_loan_request_with_wrong_return_date():
    data = get_data(get_form_data_example())
    data[F_EXPECTED_RETURN_DATE] = "1983-02-03"
    with raises(DataError):
        _issue_loan_request(data)


def test_create_loan():
    borrower = Record(name="Person1")
    l = create_loan(1234,
                    borrower,
                    "2020-03-23",
                    False,
                    "blablabla",
                    "my office")
    assert l.get_property(BOX.name).value == 1234
    assert l.get_property(BORROWER.name).value == borrower
    assert l.get_property(EXPECTED_RETURN.name).value == "2020-03-23"
    assert l.get_property(EXHAUST_CONTENTS.name).value == False
    assert l.get_property(COMMENT.name).value == "blablabla"
    assert l.get_property(DESTINATION.name).value == "my office"
